@@ -3,7 +3,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = '1.028';
+our $VERSION = '1.030';
 
 =head1 NAME
 
@@ -65,6 +65,7 @@ use constant OPTIONS => {
     'S|save'         => 'Preserve intermediate PAR files',
     's|sign'         => 'Sign PAR files',
     'T|tempcache:s'  => 'Temp cache name',
+    'u|unicode'      => 'Include Unicode stuff',
     'v|verbose:i'    => 'Verbosity level',
     'vv|verbose2',   => 'Verbosity level 2',
     'vvv|verbose3',  => 'Verbosity level 3',
@@ -683,6 +684,10 @@ sub pack_manifest_hash {
         $self->_name2moddata($name, \@modules, \@data);
     }
 
+    if ($opt->{u}) {
+        push @modules, "utf8_heavy.pl";
+    }
+
     # Skip either
     # a) all files from a .par file or
     # b) A module
@@ -732,7 +737,6 @@ sub pack_manifest_hash {
             skip    => \%skip,
 #            warn_missing => $args->{warn_missing},
         );
-        push @files, map {&$inc_find($_)} @preload;
     }
     push @files, @$input;
 
@@ -1715,7 +1719,7 @@ Audrey Tang E<lt>cpan@audreyt.orgE<gt>
 
 Steffen Mueller E<lt>smueller@cpan.orgE<gt>
 
-L<http://par.perl.org/> is the official PAR website.  You can write
+You can write
 to the mailing list at E<lt>par@perl.orgE<gt>, or send an empty mail to
 E<lt>par-subscribe@perl.orgE<gt> to participate in the discussion.
 
